Event

Enum Event 

#[non_exhaustive]
pub enum Event { Error { object_id: ObjectId, code: u32, message: String, }, DeleteId { id: u32, }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Error

fatal error event

The error event is sent out when a fatal (non-recoverable) error has occurred. The object_id argument is the object where the error occurred, most often in response to a request to that object. The code identifies the error and is defined by the object interface. As such, each interface defines its own set of error codes. The message is a brief description of the error, for (debugging) convenience.

Fields

object_id: ObjectId

object where the error occurred

code: u32

error code

message: String

error description



DeleteId

acknowledge object ID deletion

This event is used internally by the object ID management logic.

When the server stops using an object created by the client, the server sends this event. In particular, after sending this event, the server will no longer send any events that contain the object as the receiver or as an argument.

When the client receives this event, it knows that it can reuse the object ID.

Fields

id: u32

deleted object ID

Implementations

Source

impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message