#[non_exhaustive]pub struct Error(pub u32);Expand description
global error values
These errors are global and can be emitted in response to any server request.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u32Implementations
Sourceimpl Error
impl Error
Sourcepub const InvalidObject: Self
pub const InvalidObject: Self
server couldn’t find object
Sourcepub const InvalidMethod: Self
pub const InvalidMethod: Self
method doesn’t exist on the specified interface or malformed request
Sourcepub const Implementation: Self
pub const Implementation: Self
implementation error in compositor